# SCRIPT TO PLOT MAXENT RESPONSE CURVES
# Vegetation types; DEM; NDVI

# 20-02-2017
# NOTE: change working directory to correct location before running the script

# set working directory and load variables (as data.frames)
setwd("C:/Users/Sofie te Wierik/Documents/Article/Publication/Data archived/8. maxEnt output restructure/1. MaxEnt response curves output data/R/csv")
veg <- read.csv2("vegetationdata.csv")
dem <- read.csv2("demdata.csv")
ndvi <- read.csv2("ndvidata.csv")

# check data type ( = dataframe)
class(veg)
class(dem)
class(ndvi)

# VEGETATION: create std plus and minus for std plot
vstd_p <- veg$Av + veg$Std
vstd_m <- veg$Av - veg$Std

# DEM: create std plus and minus for std plot
dstd_p <- dem$Av+dem$std
dstd_m <- dem$Av-dem$std

# NDVI: create std plus and minus for std plot
nstd_p <- ndvi$Av+ndvi$Std
nstd_m <- ndvi$Av-ndvi$Std

# Create new dataframe with std - and + variables
veg_new <- cbind(veg,vstd_p,vstd_m)
dem_new <- cbind(dem,dstd_p,dstd_m)
ndvi_new <- cbind(ndvi,nstd_p,nstd_m)

# Grid for plots (3x1)
grid <- matrix(c(1,2,3), nrow = 3,ncol=1, byrow = TRUE)
layout(grid)

# VEGETATION: plot avarage veg and std (note: possibility to change 1-16 vegetation types to names!)
vegplot <- barplot(veg_new$Av, ylim = c(0,max(veg_new$vstd_p)), xlab = "Vegetation types ", ylab = "P-value", names.arg = c("UKHa","UKHb","UKHc","UKHd", "UKHe", "UKHf","EUKa","EUKb","EUKc","EUKd", "EUKe","KEGa", "KEGb", "KEGc", "SKRa","SKRb"), main = "Response curve for Vegetation types", beside = FALSE)
points(vegplot, veg_new$vstd_p, pch = 3, cex.main = 1.2, adj = 0.5)
points(vegplot, veg_new$vstd_m, pch = 3, cex.main = 1.2, adj = 0.5)

# DEM: plot average dem and std 
plot(dem_new$DEM, dem_new$Av, xlab = "Altitude (m)", ylab = "P-value", main = "Response curve for DEM", type = "l")
lines(dem_new$DEM, dem_new$dstd_p, type = "l", lty = 2)
lines(dem_new$DEM, dem_new$dstd_m, type = "l", lty = 2)

# NDVI: plot avarage veg and std 
plot(ndvi_new$NDVI, ndvi_new$Av, xlab = "Vegetation productivity (NDVI)", ylab = "P-value", main = "Response curve for NDVI", type = "l")
lines(ndvi_new$NDVI, ndvi_new$nstd_p, type = "l", lty = 2)
lines(ndvi_new$NDVI, ndvi_new$nstd_m, type = "l", lty = 2)



